@@ -36,7 +36,7 @@
 K_PLUGIN_FACTORY_DECLARATION(KcmKonqHtmlFactory)
 
 // Keep in sync with konqueror.kcfg
-static const char* DEFAULT_HOMEPAGE = "http://www.kde.org";
+static const char DEFAULT_HOMEPAGE[] = "http://www.kde.org";
 enum StartPage { ShowHomePage, ShowBlankPage, ShowAboutPage, ShowBookmarksPage };
 
 //-----------------------------------------------------------------------------
