@@ -109,18 +109,6 @@ KonqView::~KonqView()
 {
   //kDebug() << "part=" << m_pPart;
 
-  if (KonqMainWindow::s_crashlog_file) {
-     QString part_url;
-     if (m_pPart)
-        part_url = m_pPart->url().url();
-     if (part_url.isNull())
-        part_url = "";
-     QByteArray line;
-     line = ( QString("close(%1):%2\n").arg(m_randID,0,16).arg(part_url) ).toUtf8();
-     KonqMainWindow::s_crashlog_file->write(line, line.length());
-     KonqMainWindow::s_crashlog_file->flush();
-  }
-
   // We did so ourselves for passive views
   if (m_pPart != 0L)
   {
@@ -128,6 +116,9 @@ KonqView::~KonqView()
     if ( isPassiveMode() )
       disconnect( m_pPart, SIGNAL( destroyed() ), m_pMainWindow->viewManager(), SLOT( slotObjectDestroyed() ) );
 
+    if (m_pPart->manager())
+      m_pPart->manager()->removePart(m_pPart); // ~Part does this, but we have to do it before (#213876, #207173)
+
     delete m_pPart;
   }
 
@@ -144,26 +135,6 @@ void KonqView::openUrl( const KUrl &url, const QString & locationBarURL,
     kDebug() << "url=" << url << "locationBarURL=" << locationBarURL;
   setPartMimeType();
 
-  if (KonqMainWindow::s_crashlog_file) {
-     QString part_url;
-     if (m_pPart)
-        part_url = m_pPart->url().url();
-     if (part_url.isNull())
-        part_url = "";
-
-     QString url_url = url.url();
-     if (url_url.isNull())
-        url_url = QString("");
-
-     QByteArray line;
-
-     line = ( QString("closed(%1):%2\n").arg(m_randID,0,16).arg(part_url) ).toUtf8();
-     KonqMainWindow::s_crashlog_file->write(line,line.length());
-     line = ( QString("opened(%3):%4\n").arg(m_randID,0,16).arg(url_url)  ).toUtf8();
-     KonqMainWindow::s_crashlog_file->write(line,line.length());
-     KonqMainWindow::s_crashlog_file->flush();
-  }
-
   KParts::OpenUrlArguments args;
   if ( m_pPart )
       args = m_pPart->arguments();
@@ -376,16 +347,6 @@ bool KonqView::changePart(const QString &mimeType,
     switchView( viewFactory );
   }
 
-  if ( m_pMainWindow->viewManager()->activePart() != m_pPart )
-  {
-    // Make the new part active. Note that we don't do it each time we
-    // open a URL (becomes awful in view-follows-view mode), but we do
-    // each time we change the view mode.
-    // We don't do it in switchView either because it's called from the constructor too,
-    // where the location bar url isn't set yet.
-    //kDebug() << "Giving focus to new part" << m_pPart;
-    m_pMainWindow->viewManager()->setActivePart( m_pPart );
-  }
   return true;
 }
 
@@ -668,7 +629,7 @@ void KonqView::setIconURL( const KUrl & iconURL )
 
 void KonqView::setPageSecurity( int pageSecurity )
 {
-  m_pageSecurity = (KonqMainWindow::PageSecurity)pageSecurity;
+  m_pageSecurity = static_cast<KonqMainWindow::PageSecurity>(pageSecurity);
 
   if ( m_pMainWindow->currentView() == this )
     m_pMainWindow->setPageSecurity( m_pageSecurity );
@@ -1286,7 +1247,7 @@ void HistoryEntry::saveConfig( KConfigGroup& config, const QString &prefix, cons
         config.writeEntry( QString::fromLatin1( "PostContentType" ).prepend( prefix ), postContentType );
         config.writeEntry( QString::fromLatin1( "DoPost" ).prepend( prefix ), doPost );
         config.writeEntry( QString::fromLatin1( "PageReferrer" ).prepend( prefix ), pageReferrer );
-        config.writeEntry( QString::fromLatin1( "PageSecurity" ).prepend( prefix ), (int)pageSecurity );
+        config.writeEntry( QString::fromLatin1( "PageSecurity" ).prepend( prefix ), static_cast<int>(pageSecurity) );
     }
 }
 
@@ -1311,7 +1272,8 @@ void HistoryEntry::loadItem( const KConfigGroup& config, const QString &prefix,
         postContentType = config.readEntry( QString::fromLatin1( "PostContentType" ).prepend( prefix ), "" );
         doPost = config.readEntry( QString::fromLatin1( "DoPost" ).prepend( prefix ), false );
         pageReferrer = config.readEntry( QString::fromLatin1( "PageReferrer" ).prepend( prefix ), "" );
-        pageSecurity = (KonqMainWindow::PageSecurity)config.readEntry( QString::fromLatin1( "PageSecurity" ).prepend( prefix ), 0 );
+        pageSecurity = static_cast<KonqMainWindow::PageSecurity>(config.readEntry(
+                    QString::fromLatin1( "PageSecurity" ).prepend( prefix ), 0 ));
         reload = false;
     }
 }
@@ -1414,4 +1376,13 @@ bool KonqView::showsDirectory() const
     return supportsMimeType(QString::fromLatin1("inode/directory"));
 }
 
+bool KonqView::isModified() const
+{
+    if (m_pPart && (m_pPart->metaObject()->indexOfProperty("modified") != -1)) {
+        const QVariant prop = m_pPart->property("modified");
+        return prop.isValid() && prop.toBool();
+    }
+    return false;
+}
+
 #include "konqview.moc"
