@@ -3,6 +3,7 @@
 
     Copyright 2007-2008 by Robert Knight <robertknight@gmail.com>
     Copyright 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
+    Copyright 2009 by Thomas Dreibholz <dreibh@iem.uni-due.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +27,7 @@
 // Qt
 #include <QtCore/QStringList>
 #include <QtCore/QByteRef>
+#include <QUuid>
 
 // KDE
 #include <KApplication>
@@ -61,6 +63,7 @@ class ZModemDialog;
 class KONSOLEPRIVATE_EXPORT Session : public QObject
 {
 Q_OBJECT
+Q_CLASSINFO("D-Bus Interface", "org.kde.konsole.Session")
 
 public:
   Q_PROPERTY(QString name READ nameTitle)
@@ -466,6 +469,27 @@ public slots:
    */
   Q_SCRIPTABLE QString title(int role) const;
 
+  /** Returns the "friendly" version of the QUuid of this session.
+  * This is a QUuid with the braces and dashes removed, so it cannot be
+  * used to construct a new QUuid. The same text appears in the
+  * SHELL_SESSION_ID environment variable.
+  */
+  Q_SCRIPTABLE QString shellSessionId() const;
+
+  /** Sets the session's tab title format for the specified @p context to @p format.
+   *  This is an overloaded member function for setTabTitleFormat(TabTitleContext, QString)
+   *  provided for convenience since enum data types may not be
+   *  exported directly through DBus
+   */
+  Q_SCRIPTABLE void setTabTitleFormat(int context, const QString& format);
+
+  /** Returns the session's tab title format for the specified @p context.
+   * This is an overloaded member function for tabTitleFormat(TitleRole)
+   * provided for convenience since enum data types may not be
+   * exported directly through DBus
+   */
+  Q_SCRIPTABLE QString tabTitleFormat(int context) const;
+
 signals:
 
   /** Emitted when the terminal process starts. */
@@ -582,7 +606,7 @@ private:
   bool updateForegroundProcessInfo();
   ProcessInfo* updateWorkingDirectory();
 
-  int            _uniqueIdentifier;
+  QUuid            _uniqueIdentifier; // SHELL_SESSION_ID
 
   Pty*          _shellProcess;
   Emulation*    _emulation;
@@ -706,11 +730,9 @@ public:
 
 private slots:
     void sessionFinished();
+    void forwardData(const char* data, int size);
 
 private:
-    void connectPair(Session* master , Session* other);
-    void disconnectPair(Session* master , Session* other);
-    void connectAll(bool connect);
     QList<Session*> masters() const;
 
     // maps sessions to their master status
